InfiniteListView class
Constructors
InfiniteListView ({Key ? key , Axis scrollDirection = Axis.vertical , bool reverse = false , ScrollController ? controller , bool ? primary , ScrollPhysics ? physics , EdgeInsetsGeometry ? padding , double ? cacheExtent , DragStartBehavior dragStartBehavior = DragStartBehavior.start , ScrollViewKeyboardDismissBehavior ? keyboardDismissBehavior , String ? restorationId , Clip clipBehavior = Clip.hardEdge , double ? itemExtent , Widget ? prototypeItem , bool addAutomaticKeepAlives = true , bool addRepaintBoundaries = true , bool addSemanticIndexes = true , required PaginationDelegate delegate , bool shrinkWrap = false })
The InfiniteListView widget in Flutter is a specialized version of the ListView.builder widget that is designed for handling large datasets efficiently.
It uses a pagination approach to load and display data in pages as the user scrolls down the list.
This helps to improve performance and reduce memory usage, especially when dealing with large datasets that cannot be fully loaded into memory at once.
const
InfiniteListView.separated ({Key ? key , Axis scrollDirection = Axis.vertical , bool reverse = false , ScrollController ? controller , bool ? primary , ScrollPhysics ? physics , EdgeInsetsGeometry ? padding , double ? cacheExtent , DragStartBehavior dragStartBehavior = DragStartBehavior.start , ScrollViewKeyboardDismissBehavior ? keyboardDismissBehavior , String ? restorationId , Clip clipBehavior = Clip.hardEdge , double ? itemExtent , bool addAutomaticKeepAlives = true , bool addRepaintBoundaries = true , bool addSemanticIndexes = true , required PaginationDelegate delegate , required IndexedWidgetBuilder separatorBuilder , bool shrinkWrap = false })
const
Properties
addAutomaticKeepAlives
→ bool
The addAutomaticKeepAlives argument corresponds to the
SliverChildBuilderDelegate.addAutomaticKeepAlives property.
final
addRepaintBoundaries
→ bool
The addRepaintBoundaries argument corresponds to the
SliverChildBuilderDelegate.addRepaintBoundaries property.
final
addSemanticIndexes
→ bool
The addSemanticIndexes argument corresponds to the
SliverChildBuilderDelegate.addSemanticIndexes property.
final
anchor
→ double
The relative position of the zero scroll offset.
final inherited
cacheExtent
→ double ?
The viewport has an area before and after the visible area to cache items
that are about to become visible when the user scrolls.
final inherited
center
→ Key ?
The first child in the GrowthDirection.forward growth direction.
final inherited
clipBehavior
→ Clip
The content will be clipped (or not) according to this option.
final inherited
controller
→ ScrollController ?
An object that can be used to control the position to which this scroll
view is scrolled.
final inherited
delegate
→ PaginationDelegate
The PaginationDelegate contains all the necessary information for a paginated layout, such as
the item count, item builder, loading indicator builder, error indicator
builder, no more items indicator builder, loading state, error state,
and more.
final
dragStartBehavior
→ DragStartBehavior
Determines the way that drag start behavior is handled.
final inherited
hashCode
→ int
The hash code for this object.
no setter inherited
hitTestBehavior
→ HitTestBehavior
Defines the behavior of gesture detector used in this Scrollable .
final inherited
itemExtent
→ double ?
If non-null, forces the children to have the given extent in the scroll
direction.
final
key
→ Key ?
Controls how one widget replaces another widget in the tree.
final inherited
keyboardDismissBehavior
→ ScrollViewKeyboardDismissBehavior ?
The ScrollViewKeyboardDismissBehavior defines how this ScrollView will
dismiss the keyboard automatically.
final inherited
padding
→ EdgeInsetsGeometry ?
The amount of space by which to inset the children.
final inherited
paintOrder
→ SliverPaintOrder
The order in which to paint the slivers;
equivalently, the order in which to arrange them in the z-direction.
final inherited
physics
→ ScrollPhysics ?
How the scroll view should respond to user input.
final inherited
primary
→ bool ?
Whether this is the primary scroll view associated with the parent
PrimaryScrollController .
final inherited
prototypeItem
→ Widget ?
If non-null, forces the children to have the same extent as the given
widget in the scroll direction.
final
restorationId
→ String ?
Restoration ID to save and restore the scroll offset of the scrollable.
final inherited
reverse
→ bool
Whether the scroll view scrolls in the reading direction.
final inherited
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
scrollBehavior
→ ScrollBehavior ?
A ScrollBehavior that will be applied to this widget individually.
final inherited
scrollDirection
→ Axis
The Axis along which the scroll view's offset increases.
final inherited
semanticChildCount
→ int ?
The number of children that will contribute semantic information.
final inherited
shrinkWrap
→ bool
Whether the extent of the scroll view in the scrollDirection should be
determined by the contents being viewed.
final inherited
Methods
build (BuildContext context )
→ Widget
Describes the part of the user interface represented by this widget.
inherited
buildChildLayout (BuildContext context )
→ Widget
Subclasses should override this method to build the layout model.
override
buildSlivers (BuildContext context )
→ List <Widget >
Build the list of widgets to place inside the viewport.
inherited
buildViewport (BuildContext context , ViewportOffset offset , AxisDirection axisDirection , List <Widget > slivers )
→ Widget
Build the viewport.
inherited
createElement ()
→ StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren ()
→ List <DiagnosticsNode >
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
debugFillProperties (DiagnosticPropertiesBuilder properties )
→ void
Add additional properties associated with the node.
inherited
getDirection (BuildContext context )
→ AxisDirection
Returns the AxisDirection in which the scroll view scrolls.
inherited
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode ({String ? name , DiagnosticsTreeStyle ? style })
→ DiagnosticsNode
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep .
inherited
toString ({DiagnosticLevel minLevel = DiagnosticLevel.info })
→ String
A string representation of this object.
inherited
toStringDeep ({String prefixLineOne = '' , String ? prefixOtherLines , DiagnosticLevel minLevel = DiagnosticLevel.debug , int wrapWidth = 65 })
→ String
Returns a string representation of this node and its descendants.
inherited
toStringShallow ({String joiner = ', ' , DiagnosticLevel minLevel = DiagnosticLevel.debug })
→ String
Returns a one-line detailed description of the object.
inherited
toStringShort ()
→ String
A short, textual description of this widget.
inherited
easy_infinite_pagination 0.0.6