SliverInfiniteGridView class

Inheritance

Constructors

SliverInfiniteGridView({Key? key, required PaginationDelegate delegate, required SliverGridDelegate gridDelegate, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, bool enableShrinkWrapForFirstPageIndicators = false})
The SliverInfiniteGridView is similar to SliverGrid.builder, but it allows for infinite scrolling.
const

Properties

addAutomaticKeepAlives bool
The addAutomaticKeepAlives argument corresponds to the SliverChildBuilderDelegate.addAutomaticKeepAlives property.
final
addRepaintBoundaries bool
The addRepaintBoundaries argument corresponds to the SliverChildBuilderDelegate.addRepaintBoundaries property.
final
addSemanticIndexes bool
The addSemanticIndexes argument corresponds to the SliverChildBuilderDelegate.addSemanticIndexes property.
final
delegate PaginationDelegate
The PaginationDelegate contains all the necessary information for a paginated layout, such as the item count, item builder, loading indicator builder, error indicator builder, no more items indicator builder, loading state, error state, and more.
final
enableShrinkWrapForFirstPageIndicators bool
Whether to use shrink wrap for first page indicators or not.
final
gridDelegate SliverGridDelegate
The gridDelegate argument is a delegate that controls the layout of the children within the GridView and argument corresponds to the GridView.gridDelegate.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited