SliverInfiniteListView class

Inheritance

Constructors

SliverInfiniteListView({Key? key, required PaginationDelegate delegate, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, SemanticIndexCallback? semanticIndexCallback, double? itemExtent, Widget? prototypeItem, bool enableShrinkWrapForFirstPageIndicators = false})
The SliverInfiniteListView widget in Flutter is a specialized version of the SliverList.builder widget that is designed for handling large datasets efficiently. It uses a pagination approach to load and display data in pages as the user scrolls down the list. This helps to improve performance and reduce memory usage, especially when dealing with large datasets that cannot be fully loaded into memory at once.
const
SliverInfiniteListView.separated({Key? key, required PaginationDelegate delegate, required IndexedWidgetBuilder separatorBuilder, bool addAutomaticKeepAlives = true, bool addRepaintBoundaries = true, bool addSemanticIndexes = true, SemanticIndexCallback? semanticIndexCallback, double? itemExtent, bool enableShrinkWrapForFirstPageIndicators = false})
const

Properties

addAutomaticKeepAlives bool
The addAutomaticKeepAlives argument corresponds to the SliverChildBuilderDelegate.addAutomaticKeepAlives property.
final
addRepaintBoundaries bool
The addRepaintBoundaries argument corresponds to the SliverChildBuilderDelegate.addRepaintBoundaries property.
final
addSemanticIndexes bool
The addSemanticIndexes argument corresponds to the SliverChildBuilderDelegate.addSemanticIndexes property.
final
delegate PaginationDelegate
The PaginationDelegate contains all the necessary information for a paginated layout, such as the item count, item builder, loading indicator builder, error indicator builder, no more items indicator builder, loading state, error state, and more.
final
enableShrinkWrapForFirstPageIndicators bool
Whether to use shrink wrap for first page indicators or not.
final
hashCode int
The hash code for this object.
no setterinherited
itemExtent double?
If non-null, forces the children to have the given extent in the scroll direction.
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
prototypeItem Widget?
If non-null, forces the children to have the same extent as the given widget in the scroll direction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticIndexCallback SemanticIndexCallback?
A SemanticIndexCallback which is used when addSemanticIndexes is true. Defaults to providing an index for each widget.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited